Coverage for audoma_api/migrations/0002_examplesimplemodel_alter_examplemodel_json_and_more.py: 0%

1# Generated by Django 4.0.4 on 2022-05-19 06:10

2

3 import django.db.models.deletion

4 from django.db import (

5 migrations,

6 models,

7)

8

9 import audoma.django.db.fields

10

11

12 class Migration(migrations.Migration):

13

14 dependencies = [

15 ("audoma_api", "0001_initial"),

16 ]

17

18 operations = [

19 migrations.CreateModel(

20 name="ExampleSimpleModel",

21 fields=[

22 (

23 "id",

24 models.BigAutoField(

25 auto_created=True,

26 primary_key=True,

27 serialize=False,

28 verbose_name="ID",

29 ),

30 ),

31 ("name", audoma.django.db.fields.CharField(max_length=64)),

32 ("value", audoma.django.db.fields.IntegerField(default=0, null=True)),

33 ],

34 ),

35 migrations.AlterField(

36 model_name="examplemodel",

37 name="json",

38 field=audoma.django.db.fields.JSONField(),

39 ),

40 migrations.AlterField(

41 model_name="examplemodel",

42 name="money_currency",

43 field=audoma.django.db.fields.CurrencyField(

44 choices=[

45 ("AUD", "Australian Dollar"),

46 ("GBP", "British Pound"),

47 ("CNY", "Chinese Yuan"),

48 ("EUR", "Euro"),

49 ("INR", "Indian Rupee"),

50 ("JPY", "Japanese Yen"),

51 ("NZD", "New Zealand Dollar"),

52 ("CHF", "Swiss Franc"),

53 ("USD", "US Dollar"),

54 ],

55 default="XYZ",

56 max_length=3,

57 ),

58 ),

59 migrations.AlterField(

60 model_name="exampleperson",

61 name="savings_currency",

62 field=audoma.django.db.fields.CurrencyField(

63 choices=[

64 ("AUD", "Australian Dollar"),

65 ("GBP", "British Pound"),

66 ("CNY", "Chinese Yuan"),

67 ("EUR", "Euro"),

68 ("INR", "Indian Rupee"),

69 ("JPY", "Japanese Yen"),

70 ("NZD", "New Zealand Dollar"),

71 ("CHF", "Swiss Franc"),

72 ("USD", "US Dollar"),

73 ],

74 default="PLN",

75 max_length=3,

76 ),

77 ),

78 migrations.CreateModel(

79 name="ExampleTagModel",

80 fields=[

81 (

82 "id",

83 models.BigAutoField(

84 auto_created=True,

85 primary_key=True,

86 serialize=False,

87 verbose_name="ID",

88 ),

89 ),

90 ("name", audoma.django.db.fields.CharField(max_length=32)),

91 (

92 "item",

93 models.ForeignKey(

94 on_delete=django.db.models.deletion.CASCADE,

95 related_name="tags",

96 to="audoma_api.examplesimplemodel",

97 ),

98 ),

99 ],

100 ),

101 ]